bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGammaISO.move_plates
===========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGammaISO.move_plates